Changes
=======

0.0.2 (2016-11-09)
------------------

- Remove (unused) message translations


0.0.1 (2016-11-08)
------------------

- Change license to GNU LGPLv3+

- setup.py: Development Status 3 - Alpha

- Add basic docs.

- Change ``virtualenv`` command options.


0.0.0 (2016-11-08)
------------------

- Initial release.
